==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/common/classes/cache/ClaCacheUtils.php <==
<?php
$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array("_ae76ef27ae5b48757f71" . "a202718b5e5e" => base64_decode("Y2FsbF91c2VyX2Z1bmNfYX" . "JyYXk="), "_a591754a8d" . "dcdbda9c80f" . "1db4d911e14" => base64_decode("aXNfb" . "nVsbA" . "=="));




class ClaCacheUtils
{
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function GetOrLoad($key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, $_8ea414bcd8dd59cbdda78334bb203848 = false, $_fc963edf5a0382db66e7d4f122e0cb66 = 0)
    {
        $_c38eecfdb2f424d044d37360b72af861 = ClaCache::I($_8ea414bcd8dd59cbdda78334bb203848 ? ClaCache::C_SHARED : ClaCache::C_USER);
        return self::GetOrLoadExt($_c38eecfdb2f424d044d37360b72af861, $key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, $_fc963edf5a0382db66e7d4f122e0cb66);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function GetOrLoadGlobal($key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, $_fc963edf5a0382db66e7d4f122e0cb66 = 0)
    {
        return self::GetOrLoad($key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, true, $_fc963edf5a0382db66e7d4f122e0cb66);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function GetOrLoadExt(ClaCacheHandler $_c38eecfdb2f424d044d37360b72af861, $key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, $_fc963edf5a0382db66e7d4f122e0cb66 = 0)
    {
        $_c96f552040dea8086bf8bdd70059542f = $_c38eecfdb2f424d044d37360b72af861->Get($key);
        if (!$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_a591754a8ddcdbda9c80f1db4d" . "911e14"]($_c96f552040dea8086bf8bdd70059542f)) {
            return $_c96f552040dea8086bf8bdd70059542f;
        }
        $_c96f552040dea8086bf8bdd70059542f = $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_ae76ef27ae5b48757f71a202718b" . "5e5e"]($_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a);
        if (!$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_a591754a8ddcdbda9c80f1d" . "b4d911e14"]($_c96f552040dea8086bf8bdd70059542f)) {
            $_c38eecfdb2f424d044d37360b72af861->Set($key, $_c96f552040dea8086bf8bdd70059542f, $_fc963edf5a0382db66e7d4f122e0cb66);
        }
        return $_c96f552040dea8086bf8bdd70059542f;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/common/classes/cache/ClaCacheUtils.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_ae76ef27ae5b48757f71a2" . "02718b5e5e" => base64_decode("Y2FsbF91" . "c2VyX2Z1" . "bmNfYXJy" . "YXk="), "_a591754a8ddcdbda9c80" . "f1db4d911e14" => base64_decode("aXNfbn" . "VsbA=="));




class ClaCacheUtils
{
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function GetOrLoad($key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, $_8ea414bcd8dd59cbdda78334bb203848 = false, $_fc963edf5a0382db66e7d4f122e0cb66 = 0)
    {
        $_c38eecfdb2f424d044d37360b72af861 = ClaCache::I($_8ea414bcd8dd59cbdda78334bb203848 ? ClaCache::C_SHARED : ClaCache::C_USER);
        return self::GetOrLoadExt($_c38eecfdb2f424d044d37360b72af861, $key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, $_fc963edf5a0382db66e7d4f122e0cb66);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function GetOrLoadGlobal($key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, $_fc963edf5a0382db66e7d4f122e0cb66 = 0)
    {
        return self::GetOrLoad($key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, true, $_fc963edf5a0382db66e7d4f122e0cb66);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function GetOrLoadExt(ClaCacheHandler $_c38eecfdb2f424d044d37360b72af861, $key, $_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a, $_fc963edf5a0382db66e7d4f122e0cb66 = 0)
    {
        $_c96f552040dea8086bf8bdd70059542f = $_c38eecfdb2f424d044d37360b72af861->Get($key);
        if (!$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_a591754a8ddcd" . "bda9c80f1db4d9" . "11e14"]($_c96f552040dea8086bf8bdd70059542f)) {
            return $_c96f552040dea8086bf8bdd70059542f;
        }
        $_c96f552040dea8086bf8bdd70059542f = $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_ae76ef27ae5b48757" . "f71a202718b5e5e"]($_3a1d32b00c281a9ae859aa88201be7c9, $_f734973f2f4f7b11f65552dfababb99a);
        if (!$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_a591754a8ddcdbda9" . "c80f1db4d911e14"]($_c96f552040dea8086bf8bdd70059542f)) {
            $_c38eecfdb2f424d044d37360b72af861->Set($key, $_c96f552040dea8086bf8bdd70059542f, $_fc963edf5a0382db66e7d4f122e0cb66);
        }
        return $_c96f552040dea8086bf8bdd70059542f;
    }
}
